var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { Services } from '../services';
import { TraversingComponent } from '../traversing';
var Workflow = (function (_super) {
    __extends(Workflow, _super);
    function Workflow(services) {
        var _this = _super.call(this, services) || this;
        _this.services = services;
        _this.showHistory = true;
        _this.haveCommentInput = true;
        _this.commentText = '';
        _this.workflowStateChanged = new EventEmitter();
        return _this;
    }
    Workflow.prototype.onTraverse = function (target) {
        if (target.contextPath) {
            this.contextPath = target.contextPath;
            this.loadWorkflowInformation();
        }
    };
    Workflow.prototype.loadWorkflowInformation = function () {
        var component = this;
        this.services.resource.workflow(component.contextPath)
            .subscribe(function (workflowInformation) {
            component.workflowInformation = workflowInformation;
        });
    };
    Workflow.prototype.processTransition = function (event, item) {
        var _this = this;
        event.preventDefault();
        var transitionId = item['@id'].split('/').pop();
        this.services.resource.transition(this.contextPath, transitionId, { comment: this.commentText || '' })
            .subscribe(function (historyItem) {
            _this.commentText = '';
            _this.workflowStateChanged.emit(historyItem);
            _this.loadWorkflowInformation();
        }, function (error) {
            if (error.type === 'WorkflowException' || error.response && error.response.status === 404) {
                _this.workflowInformation = null;
            }
            else {
                console.error(error);
            }
        });
    };
    Workflow.prototype.currentState = function () {
        if (this.workflowInformation && this.workflowInformation.history.length > 0) {
            return this.workflowInformation.history[this.workflowInformation.history.length - 1].title;
        }
        else {
            return '';
        }
    };
    Workflow.prototype.displayTime = function (datestr) {
        var date = new Date(datestr);
        return date.toLocaleDateString() + " " + date.toLocaleTimeString();
    };
    Workflow.decorators = [
        { type: Component, args: [{
                    selector: 'plone-workflow',
                    template: "\n    <div class=\"workflow\" *ngIf=\"!!workflowInformation\">\n      <div class=\"workflow-history\" *ngIf=\"showHistory\">\n        <ul>\n          <li *ngFor=\"let item of workflowInformation?.history\">\n            <strong>{{ item.title }}</strong>\n            by <strong>{{ item.actor }}</strong> &ndash;\n            <em>{{ displayTime(item.time) }}</em>\n            <em *ngIf=\"item.comments\"> &ndash; {{ item.comments }}</em>\n          </li>\n        </ul>\n      </div>\n      <div class=\"workflow-actions\">\n        <div class=\"workflow-comment\" *ngIf=\"haveCommentInput && workflowInformation?.transitions.length\">\n        <textarea\n          placeholder=\"Your action comment\"\n          name=\"workflowComment\"\n          [(ngModel)]=\"commentText\"></textarea>\n        </div>\n        <ul>\n          <li class=\"workflow-current-state\">State: <strong>{{ currentState() }}</strong></li>\n          <li *ngFor=\"let transitionItem of workflowInformation?.transitions\">\n            <a href=\"#\" (click)=\"processTransition($event, transitionItem)\">{{ transitionItem.title }}</a>\n          </li>\n        </ul>\n      </div>\n    </div>"
                },] },
    ];
    /** @nocollapse */
    Workflow.ctorParameters = function () { return [
        { type: Services, },
    ]; };
    Workflow.propDecorators = {
        "showHistory": [{ type: Input },],
        "haveCommentInput": [{ type: Input },],
        "workflowStateChanged": [{ type: Output },],
    };
    return Workflow;
}(TraversingComponent));
export { Workflow };
