import { Directive, EventEmitter, HostListener, Input, Output } from '@angular/core';
import { APIService } from '../services/api.service';
var DownloadDirective = (function () {
    function DownloadDirective(api) {
        this.api = api;
        this.onBeforeDownloadStarted = new EventEmitter();
        this.onDownloadSuccess = new EventEmitter();
        this.onDownloadFailed = new EventEmitter();
    }
    DownloadDirective.prototype.onClick = function (event) {
        var _this = this;
        if (!!event) {
            event.preventDefault();
        }
        var namedFile = this.download;
        this.onBeforeDownloadStarted.emit({
            namedFile: namedFile,
            originalEvent: event
        });
        this.api.download(namedFile.download)
            .subscribe(function (blob) {
            if (blob instanceof Blob) {
                DownloadDirective.saveDownloaded(namedFile, blob);
                _this.onDownloadSuccess.emit({
                    namedFile: namedFile,
                    blob: blob
                });
            }
        }, function (error) {
            _this.onDownloadFailed.emit({
                error: error,
                namedFile: namedFile
            });
        });
    };
    DownloadDirective.saveDownloaded = function (namedFile, blob) {
        var a = window.document.createElement('a');
        a.href = window.URL.createObjectURL(blob, { type: namedFile['mime-type'] });
        a.download = namedFile.filename;
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
    };
    DownloadDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[download]'
                },] },
    ];
    /** @nocollapse */
    DownloadDirective.ctorParameters = function () { return [
        { type: APIService, },
    ]; };
    DownloadDirective.propDecorators = {
        "download": [{ type: Input },],
        "onBeforeDownloadStarted": [{ type: Output },],
        "onDownloadSuccess": [{ type: Output },],
        "onDownloadFailed": [{ type: Output },],
        "onClick": [{ type: HostListener, args: ['click', ['$event'],] },],
    };
    return DownloadDirective;
}());
export { DownloadDirective };
