import { EventEmitter, Injectable } from '@angular/core';
import 'rxjs/add/observable/of';
import { APIService } from './api.service';
import { AuthenticationService } from './authentication.service';
import { ConfigurationService } from './configuration.service';
var CacheService = (function () {
    function CacheService(auth, api, config) {
        var _this = this;
        this.auth = auth;
        this.api = api;
        this.config = config;
        this.cache = {};
        this.revoke = new EventEmitter();
        this.hits = {};
        var service = this;
        this.auth.isAuthenticated.subscribe(function () {
            _this.revoke.emit();
        });
        service.refreshDelay = service.config.get('CACHE_REFRESH_DELAY', 10000);
        service.maxSize = service.config.get('CACHE_MAX_SIZE', 1000);
        service.revoke.subscribe(function (revoked) {
            if (!revoked) {
                service.cache = {};
                service.hits = {};
            }
            else if (typeof revoked === 'string') {
                delete service.cache[revoked];
                delete service.hits[revoked];
            }
        });
    }
    /*
     * gets an observable
     * that broadcasts a ReplaySubject
     * which emits the response of a get request
     * during service.refreshDelay ms without sending a new http request
     */
    /*
       * gets an observable
       * that broadcasts a ReplaySubject
       * which emits the response of a get request
       * during service.refreshDelay ms without sending a new http request
       */
    CacheService.prototype.get = /*
       * gets an observable
       * that broadcasts a ReplaySubject
       * which emits the response of a get request
       * during service.refreshDelay ms without sending a new http request
       */
    function (url) {
        var _this = this;
        var service = this;
        if (!service.cache.hasOwnProperty(url)) {
            if (Object.keys(service.cache).length >= service.maxSize) {
                // TODO: do not revoke everything
                this.revoke.emit();
            }
            service.cache[url] = service.api.get(url)
                .map(function (observable) {
                service.hits[url] = 0;
                return observable;
            })
                .publishReplay(1, service.refreshDelay)
                .refCount()
                .take(1)
                .map(function (observable) {
                var hits = _this.hits[url];
                service.hits[url] = hits ? hits + 1 : 1;
                return observable;
            });
        }
        return service.cache[url];
    };
    /*
     Make the observable revoke the cache when it emits
     */
    /*
       Make the observable revoke the cache when it emits
       */
    CacheService.prototype.revoking = /*
       Make the observable revoke the cache when it emits
       */
    function (observable, revoked) {
        var service = this;
        return observable.map(function (val) {
            service.revoke.emit(revoked);
            return val;
        });
    };
    CacheService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    CacheService.ctorParameters = function () { return [
        { type: AuthenticationService, },
        { type: APIService, },
        { type: ConfigurationService, },
    ]; };
    return CacheService;
}());
export { CacheService };
