import { HttpResponse } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';
import { Observable } from 'rxjs/Observable';
var LoadingService = (function () {
    function LoadingService() {
        this.status = new BehaviorSubject(false);
        this.loadingIds = new BehaviorSubject([]);
        var service = this;
        this.loadingIds.map(function (ids) { return ids.length > 0; }).subscribe(function (isLoading) {
            if (isLoading !== service.status.getValue()) {
                service.status.next(isLoading);
            }
        });
    }
    LoadingService.prototype.begin = function (id) {
        var ids = this.loadingIds.getValue();
        ids.push(id);
        this.loadingIds.next(ids);
    };
    LoadingService.prototype.finish = function (id) {
        if (id === undefined) {
            this.loadingIds.next([]);
        }
        else {
            var ids = this.loadingIds.getValue()
                .filter(function (loadingId) { return loadingId !== id; });
            this.loadingIds.next(ids);
        }
    };
    LoadingService.prototype.isLoading = function (id) {
        return this.loadingIds.map(function (loadingIds) {
            return loadingIds.indexOf(id) >= 0;
        });
    };
    LoadingService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    LoadingService.ctorParameters = function () { return []; };
    return LoadingService;
}());
export { LoadingService };
var LoadingInterceptor = (function () {
    function LoadingInterceptor(loading) {
        this.loading = loading;
    }
    LoadingInterceptor.prototype.intercept = function (req, next) {
        var _this = this;
        var loadingId = req.method + "-" + req.urlWithParams;
        this.loading.begin(loadingId);
        return next
            .handle(req)
            .do(function (event) {
            if (event instanceof HttpResponse) {
                _this.loading.finish(loadingId);
            }
        }).catch(function (error) {
            _this.loading.finish(loadingId);
            return Observable.throw(error);
        });
    };
    LoadingInterceptor.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    LoadingInterceptor.ctorParameters = function () { return [
        { type: LoadingService, },
    ]; };
    return LoadingInterceptor;
}());
export { LoadingInterceptor };
