import { EventEmitter, Injectable } from '@angular/core';
import 'rxjs/add/observable/of';
import { ConfigurationService } from './configuration.service';
import { ResourceService } from './resource.service';
import { AuthenticationService } from './authentication.service';
var NavigationService = (function () {
    function NavigationService(auth, resource, config) {
        var _this = this;
        this.resource = resource;
        this.config = config;
        this.refreshNavigation = new EventEmitter();
        resource.resourceModified
            .merge(auth.isAuthenticated)
            .subscribe(function () {
            _this.refreshNavigation.emit();
        });
    }
    NavigationService.prototype.getNavigationFor = function (currentPath, root, depth) {
        var _this = this;
        var rootPath = this.getRoot(currentPath, root);
        return this.resource.find({
            is_default_page: false,
            path: { depth: depth }
        }, rootPath, {
            metadata_fields: ['exclude_from_nav', 'getObjPositionInParent'],
            size: 1000
        }).map(function (res) {
            var tree = { children: {} };
            res.items
                .sort(function (item) { return item.getObjPositionInParent; })
                .map(function (item) {
                var localpath = _this.config.urlToPath(item['@id']);
                var path = localpath.slice(localpath.indexOf(rootPath) + rootPath.length).split('/');
                if (path[0] === '') {
                    path.shift();
                    if (!path.length) {
                        return;
                    }
                }
                var id = path.pop() || '';
                var current = tree;
                path.map(function (folder) {
                    if (!current.children[folder]) {
                        current.children[folder] = { children: {} };
                    }
                    current = current.children[folder];
                    if (!current.children) {
                        current.children = {};
                    }
                });
                if (!current.children[id]) {
                    current.children[id] = {
                        children: {},
                        properties: null
                    };
                }
                current.children[id].properties = item;
            });
            var orderedTree = { children: _this.getOrderedChildren(tree.children), properties: tree.properties };
            if (currentPath) {
                return _this.markActive(currentPath, orderedTree);
            }
            else {
                return orderedTree;
            }
        }).filter(function (item) {
            return !item.properties || !item.properties.exclude_from_nav;
        });
    };
    NavigationService.prototype.getOrderedChildren = function (children) {
        var _this = this;
        return Object.keys(children).map(function (key) {
            var child = children[key];
            var orderedChild = child.children ? _this.getOrderedChildren(child.children) : [];
            return Object.assign({}, child, { children: orderedChild });
        }).filter(function (item) { return item.properties; }).sort(function (a, b) {
            return a.properties.getObjPositionInParent - b.properties.getObjPositionInParent;
        });
    };
    NavigationService.prototype.markActive = function (currentPath, tree) {
        var _this = this;
        if (tree.children) {
            tree.children = tree.children.map(function (item) {
                item.active = (item.properties['@id'] === currentPath);
                item.inPath = (currentPath.startsWith(item.properties['@id']));
                return _this.markActive(currentPath, item);
            });
        }
        return tree;
    };
    NavigationService.prototype.getRoot = function (currentPath, root) {
        currentPath = this.config.urlToPath(currentPath || '/');
        var rootPath = (typeof root === 'string') ? root : '/';
        if (typeof root === 'number') {
            if (root <= 0) {
                var path = currentPath.split('/');
                if (root < path.length) {
                    rootPath = path.slice(0, path.length + root).join('/');
                }
            }
        }
        return rootPath;
    };
    NavigationService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    NavigationService.ctorParameters = function () { return [
        { type: AuthenticationService, },
        { type: ResourceService, },
        { type: ConfigurationService, },
    ]; };
    return NavigationService;
}());
export { NavigationService };
