var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import { EventEmitter, Injectable } from '@angular/core';
import { Observable } from 'rxjs/Observable';
import { Vocabulary } from '../vocabularies';
import { APIService } from './api.service';
import { CacheService } from './cache.service';
import { ConfigurationService } from './configuration.service';
var ResourceService = (function () {
    function ResourceService(api, cache, configuration) {
        this.api = api;
        this.cache = cache;
        this.configuration = configuration;
        this.defaultExpand = {};
        this.resourceModified = new EventEmitter();
        this.resourceModified.subscribe(function () {
            cache.revoke.emit();
        });
    }
    ResourceService.getSearchQueryString = function (query, options) {
        if (options === void 0) { options = {}; }
        var params = [];
        Object.keys(query).map(function (index) {
            var criteria = query[index];
            if (typeof criteria === 'boolean') {
                params.push(index + '=' + (criteria ? '1' : '0'));
            }
            else if (typeof criteria === 'string') {
                params.push(index + '=' + encodeURIComponent(criteria));
            }
            else if (Array.isArray(criteria)) {
                criteria.map(function (value) {
                    params.push(index + '=' + encodeURIComponent(value));
                });
            }
            else if (criteria instanceof Date) {
                params.push(index + '=' + encodeURIComponent(criteria.toISOString()));
            }
            else {
                Object.keys(criteria).map(function (key) {
                    params.push(index + '.' + key + '=' + encodeURIComponent(criteria[key]));
                });
            }
        });
        if (options.sort_on) {
            params.push('sort_on=' + options.sort_on);
        }
        if (options.sort_order) {
            params.push('sort_order=' + options.sort_order);
        }
        if (options.metadata_fields) {
            options.metadata_fields.map(function (field) {
                params.push('metadata_fields:list=' + field);
            });
        }
        if (options.start) {
            params.push('b_start=' + options.start.toString());
        }
        if (options.size) {
            params.push('b_size=' + options.size.toString());
        }
        if (options.fullobjects) {
            params.push('fullobjects');
        }
        return params.join('&');
    };
    ResourceService.lightFileRead = function (file) {
        return Observable.create(observeFileRead);
        function observeFileRead(observer) {
            var reader = new FileReader();
            reader.readAsBinaryString(file);
            reader.onloadend = function (e) {
                var fileData = btoa(e.target.result);
                observer.next({
                    filename: file.name, data: fileData,
                    encoding: 'base64',
                    'content-type': file.type,
                });
                observer.complete();
            };
        }
    };
    ResourceService.prototype.copy = function (sourcePath, targetPath) {
        var path = targetPath + '/@copy';
        return this.emittingModified(this.api.post(targetPath + '/@copy', { source: this.api.getFullPath(sourcePath) }), path);
    };
    ResourceService.prototype.create = function (path, model) {
        return this.emittingModified(this.api.post(path, model), path);
    };
    ResourceService.prototype.delete = function (path) {
        return this.emittingModified(this.api.delete(path), path);
    };
    ResourceService.prototype.find = function (query, path, options) {
        if (path === void 0) { path = '/'; }
        if (options === void 0) { options = {}; }
        if (!path.endsWith('/')) {
            path += '/';
        }
        var queryString = ResourceService.getSearchQueryString(query, options);
        return this.cache.get(path + '@search' + '?' + queryString);
    };
    ResourceService.prototype.get = function (path, expand) {
        expand = Object.keys(this.defaultExpand).concat(expand || []);
        if (expand.length > 0) {
            path = path + '?expand=' + expand.join(',');
        }
        return this.cache.get(path);
    };
    ResourceService.prototype.move = function (sourcePath, targetPath) {
        var path = targetPath + '/@move';
        return this.emittingModified(this.api.post(path, { source: this.api.getFullPath(sourcePath) }), path);
    };
    ResourceService.prototype.transition = function (contextPath, transition, options) {
        if (options === void 0) { options = {}; }
        return this.emittingModified(this.api.post(contextPath + '/@workflow/' + transition, options), contextPath);
    };
    ResourceService.prototype.workflow = function (contextPath) {
        return this.cache.get(contextPath + '/@workflow');
    };
    ResourceService.prototype.update = function (path, model) {
        return this.emittingModified(this.api.patch(path, model), path);
    };
    ResourceService.prototype.navigation = function () {
        var _this = this;
        return this.cache.get('/@navigation')
            .map(function (data) {
            if (data) {
                return data.items
                    .filter(function (item) {
                    return !item.properties || !item.properties.exclude_from_nav;
                })
                    .map(_this.linkFromItem.bind(_this));
            }
            else {
                return [];
            }
        });
    };
    ResourceService.prototype.breadcrumbs = function (path) {
        var _this = this;
        return this.cache.get(path + '/@breadcrumbs')
            .map(function (data) {
            if (data) {
                return data.items.map(_this.linkFromItem.bind(_this));
            }
            else {
                return [];
            }
        });
    };
    ResourceService.prototype.type = function (typeId) {
        return this.cache.get('/@types/' + typeId);
    };
    ResourceService.prototype.vocabulary = function (vocabularyId) {
        return this.cache.get('/@vocabularies/' + vocabularyId)
            .map(function (jsonObject) { return new Vocabulary(jsonObject.terms); });
    };
    /*
     Make the observable emit resourceModified event when it emits
     */
    /*
       Make the observable emit resourceModified event when it emits
       */
    ResourceService.prototype.emittingModified = /*
       Make the observable emit resourceModified event when it emits
       */
    function (observable, path) {
        var service = this;
        return observable.map(function (val) {
            service.resourceModified.emit({ id: path, context: val });
            return val;
        });
    };
    ResourceService.prototype.linkFromItem = function (item) {
        return __assign({ active: false, url: item['@id'], path: this.configuration.urlToPath(item['@id']) }, item);
    };
    ResourceService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    ResourceService.ctorParameters = function () { return [
        { type: APIService, },
        { type: CacheService, },
        { type: ConfigurationService, },
    ]; };
    return ResourceService;
}());
export { ResourceService };
