import { Component } from '@angular/core';
import { URLSearchParams } from '@angular/http';
import { Services } from '../services';
var PasswordResetView = (function () {
    function PasswordResetView(services) {
        this.services = services;
        this.error = '';
    }
    PasswordResetView.prototype.ngOnInit = function () {
        var _this = this;
        var authentication = this.services.authentication;
        authentication.isAuthenticated
            .subscribe(function () {
            var authenticatedStatus = authentication.isAuthenticated.getValue();
            if (!authenticatedStatus.state) {
                _this.login = null;
            }
            else {
                _this.login = authenticatedStatus.username;
            }
        });
        // TODO: get queryString on traverse
        var params = new URLSearchParams(window.location.href.split('?')[1] || '');
        this.token = params.get('token') || null;
    };
    PasswordResetView.prototype.onSubmit = function (formInfo) {
        var _this = this;
        if (formInfo.newPasswordRepeat !== formInfo.newPassword) {
            this.error = 'Passwords does not match';
            return;
        }
        this.services.authentication.passwordReset({
            login: this.login || formInfo.login,
            token: this.token,
            newPassword: formInfo.newPassword,
            oldPassword: formInfo.oldPassword
        }).subscribe(function () {
            _this.error = '';
            _this.services.traverser.traverse('/@@login');
        }, function (error) {
            if (error.response && error.response.status === 404) {
                _this.error = 'This user does not exist';
            }
            else if (error.response && error.response.status < 500) {
                _this.error = error.message;
            }
            else {
                _this.error = 'Password reset failed.';
                console.error(error);
            }
        });
    };
    PasswordResetView.prototype.ngOnDestroy = function () {
        if (this.isAuthenticatedSub) {
            this.isAuthenticatedSub.unsubscribe();
        }
    };
    PasswordResetView.decorators = [
        { type: Component, args: [{
                    selector: 'plone-password-reset',
                    template: "<h2>Set new password</h2>\n  <form #form=\"ngForm\" (ngSubmit)=\"onSubmit(form.value)\">\n    <p class=\"error\" *ngIf=\"error\">{{ error }}</p>\n    <p *ngIf=\"!login\"><label>Login <input type=\"text\" name=\"login\" ngModel/></label></p>\n    <p *ngIf=\"!!login && !token\"><label>Old password <input type=\"password\" name=\"oldPassword\" ngModel/></label></p>\n    <p><label>New Password <input type=\"password\" name=\"newPassword\" ngModel/></label></p>\n    <p><label>Repeat password <input type=\"password\" name=\"newPasswordRepeat\" ngModel/></label></p>\n    <input type=\"submit\" value=\"Login\"/>\n  </form>"
                },] },
    ];
    /** @nocollapse */
    PasswordResetView.ctorParameters = function () { return [
        { type: Services, },
    ]; };
    return PasswordResetView;
}());
export { PasswordResetView };
